@@ -81,8 +81,8 @@ class GeneratorXmlThreeDotThree(AbstractGeneratorXml):
             dom.setAttribute('Moneda', self.data.get('moneda'))  # 'Peso Mexicano'
             # 'Opcional solo cuando moneda es distinta de MXN'
             dom.setAttribute('TipoCambio', '1' if self.data.get('moneda') == 'MXN' else self.data.get('tipo_cambio'))
-            dom.setAttribute('SubTotal', self.data.get('importe', ''))
-            dom.setAttribute('Total', self.data.get('importe_total', ''))
+            dom.setAttribute('SubTotal', self.data.get('subtotal', ''))
+            dom.setAttribute('Total', self.data.get('total', ''))
             conceptos_list = self.data.get('conceptos', [])
             if len(conceptos_list) > 0:
                 conceptos = self.dom.createElement('cfdi:Conceptos')
@@ -193,7 +193,7 @@ class GeneratorXmlThreeDotThree(AbstractGeneratorXml):
                     total_retenciones += float(retencion.get('importe', 0))
                     retenciones.appendChild(self.get_retenciones(retencion))
                 impuestos.appendChild(retenciones)
-                impuestos.setAttribute('TotalImpuestosRetenidos', str(self.data.get('retencion_iva')))
+                impuestos.setAttribute('TotalImpuestosRetenidos', str(total_retenciones))
 
             if len(self.impuestos_trasladados) > 0:
                 traslados = self.dom.createElement('cfdi:Traslados')
@@ -202,7 +202,7 @@ class GeneratorXmlThreeDotThree(AbstractGeneratorXml):
                     total_traslados += float(traslado.get('importe', 0))
                     impuestos.appendChild(self.get_traslados(traslado))
                 impuestos.appendChild(traslados)
-                impuestos.setAttribute('TotalImpuestosTrasladados',str(self.data.get('iva')))
+                impuestos.setAttribute('TotalImpuestosTrasladados', str(total_traslados))
             return impuestos
         except Exception as e:
             raise Exception("Ocurrio un error. Error::: " + str(e))
